.. Copyright (c) 2016, Johan Mabille, Sylvain Corlay and Wolf Vollprecht

   Distributed under the terms of the BSD 3-Clause License.

   The full license is in the file LICENSE, distributed with this software.

Index related functions
=======================

Defined in ``xtensor/xoperation.hpp``

.. _wherec-op-ref:
.. doxygenfunction:: where(const T&)
   :project: xtensor

.. _nonzero-op-ref:
.. doxygenfunction:: nonzero(const T&)
   :project: xtensor

.. _argwhere-op-ref:
.. doxygenfunction:: argwhere
   :project: xtensor

.. _frindices-op-ref:
.. doxygenfunction:: from_indices
   :project: xtensor
